@@ -34,6 +34,7 @@
 #include <string.h>
 #include <gio/gio.h>
 #include <stdlib.h>
+#include <colord.h>
 #include <gtk/gtk.h>
 #ifdef HAVE_VTE
 #include <vte/vte.h>
@@ -41,11 +42,9 @@
 #include <canberra-gtk.h>
 
 #include "gcm-calibrate-argyll.h"
-#include "gcm-sensor-client.h"
 #include "gcm-utils.h"
 #include "gcm-x11-screen.h"
 #include "gcm-print.h"
-#include "gcm-color.h"
 #include "gcm-calibrate-dialog.h"
 
 #define FIXED_ARGYLL
@@ -151,7 +150,7 @@ static guint
 gcm_calibrate_argyll_printer_get_patches (GcmCalibrateArgyll *calibrate_argyll)
 {
 	guint patches = 180;
-	GcmSensorKind sensor_kind;
+	CdSensorKind sensor_kind;
 	GcmCalibratePrecision precision;
 
 	/* we care about the kind */
@@ -169,8 +168,8 @@ gcm_calibrate_argyll_printer_get_patches (GcmCalibrateArgyll *calibrate_argyll)
 
 #ifdef USE_DOUBLE_DENSITY
 	/* using double density, so we can double the patch count */
-	if (sensor_kind == GCM_SENSOR_KIND_COLOR_MUNKI ||
-	    sensor_kind == GCM_SENSOR_KIND_SPECTRO_SCAN) {
+	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI ||
+	    sensor_kind == CD_SENSOR_KIND_SPECTRO_SCAN) {
 		patches *= 2;
 	}
 #endif
@@ -185,20 +184,20 @@ gcm_calibrate_argyll_printer_get_patches (GcmCalibrateArgyll *calibrate_argyll)
 static const gchar *
 gcm_calibrate_argyll_get_sensor_image_attach (GcmCalibrateArgyll *calibrate_argyll)
 {
-	GcmSensorKind sensor_kind;
+	CdSensorKind sensor_kind;
 
 	g_object_get (calibrate_argyll, "sensor-kind", &sensor_kind, NULL);
-	if (sensor_kind == GCM_SENSOR_KIND_HUEY)
+	if (sensor_kind == CD_SENSOR_KIND_HUEY)
 		return "huey-attach.svg";
-	if (sensor_kind == GCM_SENSOR_KIND_COLOR_MUNKI)
+	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI)
 		return "munki-attach.svg";
-	if (sensor_kind == GCM_SENSOR_KIND_SPYDER)
+	if (sensor_kind == CD_SENSOR_KIND_SPYDER)
 		return "spyder-attach.svg";
-	if (sensor_kind == GCM_SENSOR_KIND_COLORIMTRE_HCFR)
+	if (sensor_kind == CD_SENSOR_KIND_COLORIMTRE_HCFR)
 		return "hcfr-attach.svg";
-	if (sensor_kind == GCM_SENSOR_KIND_I1_PRO)
+	if (sensor_kind == CD_SENSOR_KIND_I1_PRO)
 		return "i1-attach.svg";
-	if (sensor_kind == GCM_SENSOR_KIND_DTP94)
+	if (sensor_kind == CD_SENSOR_KIND_DTP94)
 		return "dtp94-attach.svg";
 	return NULL;
 }
@@ -209,10 +208,10 @@ gcm_calibrate_argyll_get_sensor_image_attach (GcmCalibrateArgyll *calibrate_argy
 static const gchar *
 gcm_calibrate_argyll_get_sensor_image_calibrate (GcmCalibrateArgyll *calibrate_argyll)
 {
-	GcmSensorKind sensor_kind;
+	CdSensorKind sensor_kind;
 
 	g_object_get (calibrate_argyll, "sensor-kind", &sensor_kind, NULL);
-	if (sensor_kind == GCM_SENSOR_KIND_COLOR_MUNKI)
+	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI)
 		return "munki-calibrate.svg";
 	return NULL;
 }
@@ -223,10 +222,10 @@ gcm_calibrate_argyll_get_sensor_image_calibrate (GcmCalibrateArgyll *calibrate_a
 static const gchar *
 gcm_calibrate_argyll_get_sensor_image_screen (GcmCalibrateArgyll *calibrate_argyll)
 {
-	GcmSensorKind sensor_kind;
+	CdSensorKind sensor_kind;
 
 	g_object_get (calibrate_argyll, "sensor-kind", &sensor_kind, NULL);
-	if (sensor_kind == GCM_SENSOR_KIND_COLOR_MUNKI)
+	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI)
 		return "munki-screen.svg";
 	return NULL;
 }
@@ -472,7 +471,7 @@ gcm_calibrate_argyll_display_neutralise (GcmCalibrateArgyll *calibrate_argyll, G
 	g_ptr_array_add (array, g_strdup ("-m"));
 	g_ptr_array_add (array, g_strdup_printf ("-d%i", priv->display));
 	g_ptr_array_add (array, g_strdup_printf ("-y%c", kind));
-//	g_ptr_array_add (array, g_strdup ("-p 0.8,0.5,1.0"));
+	g_ptr_array_add (array, g_strdup ("-p 0.5,0.5,1.2"));
 	g_ptr_array_add (array, g_strdup (basename));
 	argv = gcm_utils_ptr_array_to_strv (array);
 	gcm_calibrate_argyll_debug_argv (command, argv);
@@ -621,7 +620,7 @@ gcm_calibrate_argyll_display_generate_patches (GcmCalibrateArgyll *calibrate_arg
 	gchar *basename = NULL;
 	const gchar *title;
 	const gchar *message;
-	GcmDeviceKind device_kind;
+	CdDeviceKind device_kind;
 
 	/* get shared data */
 	g_object_get (calibrate_argyll,
@@ -654,7 +653,7 @@ gcm_calibrate_argyll_display_generate_patches (GcmCalibrateArgyll *calibrate_arg
 	g_ptr_array_add (array, g_strdup (command));
 #endif
 	g_ptr_array_add (array, g_strdup ("-v"));
-	if (device_kind == GCM_DEVICE_KIND_PRINTER) {
+	if (device_kind == CD_DEVICE_KIND_PRINTER) {
 		/* print RGB */
 		g_ptr_array_add (array, g_strdup ("-d2"));
 
@@ -666,9 +665,9 @@ gcm_calibrate_argyll_display_generate_patches (GcmCalibrateArgyll *calibrate_arg
 	}
 
 	/* get number of patches */
-	if (device_kind == GCM_DEVICE_KIND_DISPLAY)
+	if (device_kind == CD_DEVICE_KIND_DISPLAY)
 		g_ptr_array_add (array, g_strdup_printf ("-f%i", gcm_calibrate_argyll_display_get_patches (calibrate_argyll)));
-	else if (device_kind == GCM_DEVICE_KIND_PRINTER)
+	else if (device_kind == CD_DEVICE_KIND_PRINTER)
 		g_ptr_array_add (array, g_strdup_printf ("-f%i", gcm_calibrate_argyll_printer_get_patches (calibrate_argyll)));
 
 	g_ptr_array_add (array, g_strdup (basename));
@@ -1356,7 +1355,7 @@ gcm_calibrate_argyll_remove_temp_files (GcmCalibrateArgyll *calibrate_argyll, GE
  * gcm_calibrate_argyll_display:
  **/
 static gboolean
-gcm_calibrate_argyll_display (GcmCalibrate *calibrate, GtkWindow *window, GError **error)
+gcm_calibrate_argyll_display (GcmCalibrate *calibrate, CdSensor *sensor, GtkWindow *window, GError **error)
 {
 	GcmCalibrateArgyll *calibrate_argyll = GCM_CALIBRATE_ARGYLL(calibrate);
 	GcmCalibrateArgyllPrivate *priv = calibrate_argyll->priv;
@@ -1501,7 +1500,7 @@ out:
  * gcm_calibrate_argyll_spotread:
  **/
 static gboolean
-gcm_calibrate_argyll_spotread (GcmCalibrate *calibrate, GtkWindow *window, GError **error)
+gcm_calibrate_argyll_spotread (GcmCalibrate *calibrate, CdSensor *sensor, GtkWindow *window, GError **error)
 {
 	GcmCalibrateArgyll *calibrate_argyll = GCM_CALIBRATE_ARGYLL(calibrate);
 	GcmCalibrateArgyllPrivate *priv = calibrate_argyll->priv;
@@ -1530,25 +1529,25 @@ out:
 static const gchar *
 gcm_calibrate_argyll_get_sensor_target (GcmCalibrateArgyll *calibrate_argyll)
 {
-	GcmSensorKind sensor_kind;
+	CdSensorKind sensor_kind;
 
 	g_object_get (calibrate_argyll,
 		      "sensor-kind", &sensor_kind,
 		      NULL);
 
-	if (sensor_kind == GCM_SENSOR_KIND_DTP20)
+	if (sensor_kind == CD_SENSOR_KIND_DTP20)
 		return "20";
-	if (sensor_kind == GCM_SENSOR_KIND_DTP22)
+	if (sensor_kind == CD_SENSOR_KIND_DTP22)
 		return "22";
-	if (sensor_kind == GCM_SENSOR_KIND_DTP41)
+	if (sensor_kind == CD_SENSOR_KIND_DTP41)
 		return "41";
-	if (sensor_kind == GCM_SENSOR_KIND_DTP51)
+	if (sensor_kind == CD_SENSOR_KIND_DTP51)
 		return "51";
-	if (sensor_kind == GCM_SENSOR_KIND_SPECTRO_SCAN)
+	if (sensor_kind == CD_SENSOR_KIND_SPECTRO_SCAN)
 		return "SS";
-	if (sensor_kind == GCM_SENSOR_KIND_I1_PRO)
+	if (sensor_kind == CD_SENSOR_KIND_I1_PRO)
 		return "i1";
-	if (sensor_kind == GCM_SENSOR_KIND_COLOR_MUNKI)
+	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI)
 		return "CM";
 	return NULL;
 }
@@ -1567,7 +1566,7 @@ gcm_calibrate_argyll_display_generate_targets (GcmCalibrateArgyll *calibrate_arg
 	gchar *basename = NULL;
 	const gchar *title;
 	const gchar *message;
-	GcmSensorKind sensor_kind;
+	CdSensorKind sensor_kind;
 
 	/* get shared data */
 	g_object_get (calibrate_argyll,
@@ -1607,8 +1606,8 @@ gcm_calibrate_argyll_display_generate_targets (GcmCalibrateArgyll *calibrate_arg
 
 #ifdef USE_DOUBLE_DENSITY
 	/* use double density */
-	if (sensor_kind == GCM_SENSOR_KIND_COLOR_MUNKI ||
-	    sensor_kind == GCM_SENSOR_KIND_SPECTRO_SCAN) {
+	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI ||
+	    sensor_kind == CD_SENSOR_KIND_SPECTRO_SCAN) {
 		g_ptr_array_add (array, g_strdup ("-h"));
 	}
 #endif
@@ -1858,7 +1857,7 @@ out:
  * gcm_calibrate_argyll_printer:
  **/
 static gboolean
-gcm_calibrate_argyll_printer (GcmCalibrate *calibrate, GtkWindow *window, GError **error)
+gcm_calibrate_argyll_printer (GcmCalibrate *calibrate, CdSensor *sensor, GtkWindow *window, GError **error)
 {
 	gboolean ret;
 	gchar *cmdline = NULL;
@@ -2099,7 +2098,7 @@ out:
  * gcm_calibrate_argyll_device:
  **/
 static gboolean
-gcm_calibrate_argyll_device (GcmCalibrate *calibrate, GtkWindow *window, GError **error)
+gcm_calibrate_argyll_device (GcmCalibrate *calibrate, CdSensor *sensor, GtkWindow *window, GError **error)
 {
 	GcmCalibrateArgyll *calibrate_argyll = GCM_CALIBRATE_ARGYLL(calibrate);
 	GcmCalibrateArgyllPrivate *priv = calibrate_argyll->priv;
@@ -2454,10 +2453,10 @@ gcm_calibrate_argyll_process_output_cmd (GcmCalibrateArgyll *calibrate_argyll, c
 	/* spot read result */
 	found = g_strstr_len (line, -1, "Result is XYZ");
 	if (found != NULL) {
-		GcmColorXYZ *xyz;
+		CdColorXYZ *xyz;
 		g_warning ("line=%s", line);
 		split = g_strsplit (line, " ", -1);
-		xyz = gcm_color_new_XYZ ();
+		xyz = cd_color_xyz_new ();
 		g_object_set (xyz,
 			      "cie-x", g_ascii_strtod (split[4], NULL),
 			      "cie-y", g_ascii_strtod (split[5], NULL),
@@ -2468,7 +2467,7 @@ gcm_calibrate_argyll_process_output_cmd (GcmCalibrateArgyll *calibrate_argyll, c
 			      NULL);
 		priv->done_spot_read = TRUE;
 		gcm_calibrate_dialog_response (priv->calibrate_dialog, GTK_RESPONSE_CANCEL);
-		gcm_color_free_XYZ (xyz);
+		cd_color_xyz_free (xyz);
 		goto out;
 	}
 
@@ -2874,6 +2873,7 @@ gcm_calibrate_argyll_init (GcmCalibrateArgyll *calibrate_argyll)
 
 	/* get screen */
 	calibrate_argyll->priv->screen = gcm_x11_screen_new ();
+	gcm_x11_screen_assign (calibrate_argyll->priv->screen, NULL, NULL);
 
 	/* add vte widget */
 #ifdef HAVE_VTE
