@@ -23,8 +23,8 @@
 #define __GCM_CALIBRATE_H
 
 #include <glib-object.h>
-
-#include "gcm-device.h"
+#include <gtk/gtk.h>
+#include <colord.h>
 
 G_BEGIN_DECLS
 
@@ -50,15 +50,19 @@ struct _GcmCalibrateClass
 	GObjectClass	parent_class;
 	/* vtable */
 	gboolean	 (*calibrate_display)		(GcmCalibrate	*calibrate,
+							 CdSensor	*sensor,
 							 GtkWindow	*window,
 							 GError		**error);
 	gboolean	 (*calibrate_device)		(GcmCalibrate	*calibrate,
+							 CdSensor	*sensor,
 							 GtkWindow	*window,
 							 GError		**error);
 	gboolean	 (*calibrate_printer)		(GcmCalibrate	*calibrate,
+							 CdSensor	*sensor,
 							 GtkWindow	*window,
 							 GError		**error);
 	gboolean	 (*calibrate_spotread)		(GcmCalibrate	*calibrate,
+							 CdSensor	*sensor,
 							 GtkWindow	*window,
 							 GError		**error);
 	/* padding for future expansion */
@@ -69,8 +73,7 @@ struct _GcmCalibrateClass
 	void (*_gcm_reserved5) (void);
 };
 
-typedef enum
-{
+typedef enum {
 	GCM_CALIBRATE_ERROR_USER_ABORT,
 	GCM_CALIBRATE_ERROR_NO_SUPPORT,
 	GCM_CALIBRATE_ERROR_NO_DATA,
@@ -130,16 +133,20 @@ gboolean	 gcm_calibrate_spotread			(GcmCalibrate	*calibrate,
 							 GtkWindow	*window,
 							 GError		**error);
 gboolean	 gcm_calibrate_set_from_device		(GcmCalibrate	*calibrate,
-							 GcmDevice	*device,
+							 CdDevice	*device,
+							 CdSensor	*sensor,
 							 GError		**error);
 gboolean	 gcm_calibrate_set_from_exif		(GcmCalibrate	*calibrate,
 							 const gchar	*filename,
 							 GError		**error);
-const gchar	*gcm_calibrate_get_model_fallback	(GcmCalibrate	*calibrate);
-const gchar	*gcm_calibrate_get_description_fallback	(GcmCalibrate	*calibrate);
-const gchar	*gcm_calibrate_get_manufacturer_fallback (GcmCalibrate	*calibrate);
-const gchar	*gcm_calibrate_get_device_fallback	(GcmCalibrate	*calibrate);
 const gchar	*gcm_calibrate_get_filename_result	(GcmCalibrate	*calibrate);
+const gchar	*gcm_calibrate_get_working_path		(GcmCalibrate	*calibrate);
+const gchar	*gcm_calibrate_get_basename		(GcmCalibrate	*calibrate);
+
+gchar		*gcm_calibrate_get_profile_copyright	(GcmCalibrate	*calibrate);
+gchar		*gcm_calibrate_get_profile_description	(GcmCalibrate	*calibrate);
+gchar		*gcm_calibrate_get_profile_model	(GcmCalibrate	*calibrate);
+gchar		*gcm_calibrate_get_profile_manufacturer	(GcmCalibrate	*calibrate);
 
 G_END_DECLS
 
