@@ -33,12 +33,11 @@
 #include <string.h>
 #include <gio/gio.h>
 #include <stdlib.h>
+#include <lcms2.h>
 
 #include "gcm-edid.h"
 #include "gcm-tables.h"
 
-#include "egg-debug.h"
-
 static void     gcm_edid_finalize	(GObject     *object);
 
 #define GCM_EDID_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GCM_TYPE_EDID, GcmEdidPrivate))
@@ -59,6 +58,10 @@ struct _GcmEdidPrivate
 	guint				 width;
 	guint				 height;
 	gfloat				 gamma;
+	CdColorYxy			*red;
+	CdColorYxy			*green;
+	CdColorYxy			*blue;
+	CdColorYxy			*white;
 	GcmTables			*tables;
 };
 
@@ -73,6 +76,10 @@ enum {
 	PROP_PNP_ID,
 	PROP_WIDTH,
 	PROP_HEIGHT,
+	PROP_RED,
+	PROP_GREEN,
+	PROP_BLUE,
+	PROP_WHITE,
 	PROP_LAST
 };
 
@@ -92,9 +99,13 @@ G_DEFINE_TYPE (GcmEdid, gcm_edid, G_TYPE_OBJECT)
 #define GCM_DESCRIPTOR_ALPHANUMERIC_DATA_STRING		0xfe
 #define GCM_DESCRIPTOR_COLOR_POINT			0xfb
 
-
 /**
  * gcm_edid_get_monitor_name:
+ * @edid: a valid #GcmEdid instance
+ *
+ * Gets the monitor name.
+ *
+ * Return value: a null terminaled string value
  **/
 const gchar *
 gcm_edid_get_monitor_name (GcmEdid *edid)
@@ -105,6 +116,11 @@ gcm_edid_get_monitor_name (GcmEdid *edid)
 
 /**
  * gcm_edid_get_vendor_name:
+ * @edid: a valid #GcmEdid instance
+ *
+ * Gets the vendor name.
+ *
+ * Return value: a null terminaled string value
  **/
 const gchar *
 gcm_edid_get_vendor_name (GcmEdid *edid)
@@ -119,6 +135,11 @@ gcm_edid_get_vendor_name (GcmEdid *edid)
 
 /**
  * gcm_edid_get_serial_number:
+ * @edid: a valid #GcmEdid instance
+ *
+ * Gets the device serial number.
+ *
+ * Return value: a null terminaled string value
  **/
 const gchar *
 gcm_edid_get_serial_number (GcmEdid *edid)
@@ -129,6 +150,11 @@ gcm_edid_get_serial_number (GcmEdid *edid)
 
 /**
  * gcm_edid_get_eisa_id:
+ * @edid: a valid #GcmEdid instance
+ *
+ * Gets the EISA ID.
+ *
+ * Return value: a null terminaled string value
  **/
 const gchar *
 gcm_edid_get_eisa_id (GcmEdid *edid)
@@ -139,6 +165,12 @@ gcm_edid_get_eisa_id (GcmEdid *edid)
 
 /**
  * gcm_edid_get_checksum:
+ * @edid: a valid #GcmEdid instance
+ *
+ * Gets the EDID MD5 checksum, which is often useful to compare binary
+ * blobs.
+ *
+ * Return value: a null terminaled string value
  **/
 const gchar *
 gcm_edid_get_checksum (GcmEdid *edid)
@@ -149,6 +181,11 @@ gcm_edid_get_checksum (GcmEdid *edid)
 
 /**
  * gcm_edid_get_pnp_id:
+ * @edid: a valid #GcmEdid instance
+ *
+ * Gets the device PNP ID..
+ *
+ * Return value: a null terminaled string value
  **/
 const gchar *
 gcm_edid_get_pnp_id (GcmEdid *edid)
@@ -159,6 +196,11 @@ gcm_edid_get_pnp_id (GcmEdid *edid)
 
 /**
  * gcm_edid_get_width:
+ * @edid: a valid #GcmEdid instance
+ *
+ * Gets the width of the panel.
+ *
+ * Return value: the width in mm.
  **/
 guint
 gcm_edid_get_width (GcmEdid *edid)
@@ -169,6 +211,11 @@ gcm_edid_get_width (GcmEdid *edid)
 
 /**
  * gcm_edid_get_height:
+ * @edid: a valid #GcmEdid instance
+ *
+ * Gets the panel height.
+ *
+ * Return value: the height in mm.
  **/
 guint
 gcm_edid_get_height (GcmEdid *edid)
@@ -179,6 +226,11 @@ gcm_edid_get_height (GcmEdid *edid)
 
 /**
  * gcm_edid_get_gamma:
+ * @edid: a valid #GcmEdid instance
+ *
+ * Gets the monitor gamma.
+ *
+ * Return value: the gamma value, although this is typically 2.2
  **/
 gfloat
 gcm_edid_get_gamma (GcmEdid *edid)
@@ -187,8 +239,71 @@ gcm_edid_get_gamma (GcmEdid *edid)
 	return edid->priv->gamma;
 }
 
+/**
+ * gcm_edid_get_red:
+ * @edid: a valid #GcmEdid instance
+ *
+ * Gets the monitor red chromaticity value.
+ *
+ * Return value: the #CdColorYxy value
+ **/
+const CdColorYxy *
+gcm_edid_get_red (GcmEdid *edid)
+{
+	g_return_val_if_fail (GCM_IS_EDID (edid), NULL);
+	return edid->priv->red;
+}
+
+/**
+ * gcm_edid_get_green:
+ * @edid: a valid #GcmEdid instance
+ *
+ * Gets the monitor green chromaticity value.
+ *
+ * Return value: the #CdColorYxy value
+ **/
+const CdColorYxy *
+gcm_edid_get_green (GcmEdid *edid)
+{
+	g_return_val_if_fail (GCM_IS_EDID (edid), NULL);
+	return edid->priv->green;
+}
+
+/**
+ * gcm_edid_get_blue:
+ * @edid: a valid #GcmEdid instance
+ *
+ * Gets the monitor red chromaticity value.
+ *
+ * Return value: the #CdColorYxy value
+ **/
+const CdColorYxy *
+gcm_edid_get_blue (GcmEdid *edid)
+{
+	g_return_val_if_fail (GCM_IS_EDID (edid), NULL);
+	return edid->priv->blue;
+}
+
+/**
+ * gcm_edid_get_white:
+ * @edid: a valid #GcmEdid instance
+ *
+ * Gets the monitor white chromaticity value.
+ *
+ * Return value: the #CdColorYxy value
+ **/
+const CdColorYxy *
+gcm_edid_get_white (GcmEdid *edid)
+{
+	g_return_val_if_fail (GCM_IS_EDID (edid), NULL);
+	return edid->priv->white;
+}
+
 /**
  * gcm_edid_reset:
+ * @edid: a valid #GcmEdid instance
+ *
+ * Resets all the cached values in this object.
  **/
 void
 gcm_edid_reset (GcmEdid *edid)
@@ -267,6 +382,8 @@ static gchar *
 gcm_edid_parse_string (const guint8 *data)
 {
 	gchar *text;
+	guint i;
+	guint replaced = 0;
 
 	/* copy 12 bytes */
 	text = g_strndup ((const gchar *) data, 12);
@@ -281,26 +398,73 @@ gcm_edid_parse_string (const guint8 *data)
 	if (text[0] == '\0') {
 		g_free (text);
 		text = NULL;
+		goto out;
 	}
+
+	/* ensure string is printable */
+	for (i=0; text[i] != '\0'; i++) {
+		if (!g_ascii_isprint (text[i])) {
+			text[i] = '-';
+			replaced++;
+		}
+	}
+
+	/* if the string is junk, ignore the string */
+	if (replaced > 4) {
+		g_free (text);
+		text = NULL;
+		goto out;
+	}
+out:
 	return text;
 }
 
+/**
+ * gcm_edid_get_white_temperature:
+ **/
+static gdouble
+gcm_edid_get_white_temperature (CdColorYxy *yxy)
+{
+	cmsCIExyY xyY;
+	gboolean ret;
+	gdouble temp;
+
+	/* use LCMS to convert the xyY measurement to temperature */
+	xyY.x = yxy->x;
+	xyY.y = yxy->y;
+	xyY.Y = 1.0f;
+	ret = cmsTempFromWhitePoint (&temp, &xyY);
+	if (!ret)
+		temp = -1.0f;
+	return temp;
+}
+
 /**
  * gcm_edid_parse:
+ * @edid: a valid #GcmEdid instance
+ * @data: the EDID block
+ * @length: the data length, typically a multiple of 128
+ * @error: a valid #GError or %NULL
+ *
+ * Parses an EDID block, checking for sanity and decoding anything
+ * important.
+ *
+ * Return value: %TRUE for success.
  **/
 gboolean
-gcm_edid_parse (GcmEdid *edid, const guint8 *data, GError **error)
+gcm_edid_parse (GcmEdid *edid, const guint8 *data, gsize length, GError **error)
 {
 	gboolean ret = TRUE;
 	guint i;
 	GcmEdidPrivate *priv = edid->priv;
 	guint32 serial;
 	guint extension_blocks;
-	gdouble x, y;
 	gchar *tmp;
+	gdouble temp_float;
 
 	g_return_val_if_fail (GCM_IS_EDID (edid), FALSE);
 	g_return_val_if_fail (data != NULL, FALSE);
+	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
 	/* check header */
 	if (data[0] != 0x00 || data[1] != 0xff) {
@@ -320,7 +484,7 @@ gcm_edid_parse (GcmEdid *edid, const guint8 *data, GError **error)
 	priv->pnp_id[0] = 'A' + ((data[GCM_EDID_OFFSET_PNPID+0] & 0x7c) / 4) - 1;
 	priv->pnp_id[1] = 'A' + ((data[GCM_EDID_OFFSET_PNPID+0] & 0x3) * 8) + ((data[GCM_EDID_OFFSET_PNPID+1] & 0xe0) / 32) - 1;
 	priv->pnp_id[2] = 'A' + (data[GCM_EDID_OFFSET_PNPID+1] & 0x1f) - 1;
-	egg_debug ("PNPID: %s", priv->pnp_id);
+	g_debug ("PNPID: %s", priv->pnp_id);
 
 	/* maybe there isn't a ASCII serial number descriptor, so use this instead */
 	serial = (guint32) data[GCM_EDID_OFFSET_SERIAL+0];
@@ -329,7 +493,7 @@ gcm_edid_parse (GcmEdid *edid, const guint8 *data, GError **error)
 	serial += (guint32) data[GCM_EDID_OFFSET_SERIAL+3] * 0x1000000;
 	if (serial > 0) {
 		priv->serial_number = g_strdup_printf ("%" G_GUINT32_FORMAT, serial);
-		egg_debug ("Serial: %s", priv->serial_number);
+		g_debug ("Serial: %s", priv->serial_number);
 	}
 
 	/* get the size */
@@ -345,31 +509,35 @@ gcm_edid_parse (GcmEdid *edid, const guint8 *data, GError **error)
 	/* get gamma */
 	if (data[GCM_EDID_OFFSET_GAMMA] == 0xff) {
 		priv->gamma = 1.0f;
-		egg_debug ("gamma is stored in an extension block");
+		g_debug ("gamma is stored in an extension block");
 	} else {
 		priv->gamma = ((gfloat) data[GCM_EDID_OFFSET_GAMMA] / 100) + 1;
-		egg_debug ("gamma is reported as %f", priv->gamma);
+		g_debug ("gamma is reported as %f", priv->gamma);
 	}
 
 	/* get color red */
-	x = gcm_edid_decode_fraction (data[0x1b], gcm_edid_get_bits (data[0x19], 6, 7));
-	y = gcm_edid_decode_fraction (data[0x1c], gcm_edid_get_bits (data[0x19], 5, 4));
-	egg_debug ("red x=%f,y=%f", x, y);
+	priv->red->x = gcm_edid_decode_fraction (data[0x1b], gcm_edid_get_bits (data[0x19], 6, 7));
+	priv->red->y = gcm_edid_decode_fraction (data[0x1c], gcm_edid_get_bits (data[0x19], 5, 4));
+	g_debug ("red x=%f,y=%f", priv->red->x, priv->red->y);
 
 	/* get color green */
-	x = gcm_edid_decode_fraction (data[0x1d], gcm_edid_get_bits (data[0x19], 2, 3));
-	y = gcm_edid_decode_fraction (data[0x1e], gcm_edid_get_bits (data[0x19], 0, 1));
-	egg_debug ("green x=%f,y=%f", x, y);
+	priv->green->x = gcm_edid_decode_fraction (data[0x1d], gcm_edid_get_bits (data[0x19], 2, 3));
+	priv->green->y = gcm_edid_decode_fraction (data[0x1e], gcm_edid_get_bits (data[0x19], 0, 1));
+	g_debug ("green x=%f,y=%f", priv->green->x, priv->green->y);
 
 	/* get color blue */
-	x = gcm_edid_decode_fraction (data[0x1f], gcm_edid_get_bits (data[0x1a], 6, 7));
-	y = gcm_edid_decode_fraction (data[0x20], gcm_edid_get_bits (data[0x1a], 4, 5));
-	egg_debug ("blue x=%f,y=%f", x, y);
+	priv->blue->x = gcm_edid_decode_fraction (data[0x1f], gcm_edid_get_bits (data[0x1a], 6, 7));
+	priv->blue->y = gcm_edid_decode_fraction (data[0x20], gcm_edid_get_bits (data[0x1a], 4, 5));
+	g_debug ("blue x=%f,y=%f", priv->blue->x, priv->blue->y);
 
 	/* get color white */
-	x = gcm_edid_decode_fraction (data[0x21], gcm_edid_get_bits (data[0x1a], 2, 3));
-	y = gcm_edid_decode_fraction (data[0x22], gcm_edid_get_bits (data[0x1a], 0, 1));
-	egg_debug ("white x=%f,y=%f", x, y);
+	priv->white->x = gcm_edid_decode_fraction (data[0x21], gcm_edid_get_bits (data[0x1a], 2, 3));
+	priv->white->y = gcm_edid_decode_fraction (data[0x22], gcm_edid_get_bits (data[0x1a], 0, 1));
+	temp_float = gcm_edid_get_white_temperature (priv->white);
+	g_debug ("white x=%f,y=%f (%.2fK)",
+		 priv->white->x,
+		 priv->white->y,
+		 temp_float);
 
 	/* parse EDID data */
 	for (i=GCM_EDID_OFFSET_DATA_BLOCKS; i <= GCM_EDID_OFFSET_LAST_BLOCK; i+=18) {
@@ -393,7 +561,7 @@ gcm_edid_parse (GcmEdid *edid, const guint8 *data, GError **error)
 				priv->serial_number = tmp;
 			}
 		} else if (data[i+3] == GCM_DESCRIPTOR_COLOR_MANAGEMENT_DATA) {
-			egg_warning ("failing to parse color management data");
+			g_warning ("failing to parse color management data");
 		} else if (data[i+3] == GCM_DESCRIPTOR_ALPHANUMERIC_DATA_STRING) {
 			tmp = gcm_edid_parse_string (&data[i+5]);
 			if (tmp != NULL) {
@@ -402,14 +570,14 @@ gcm_edid_parse (GcmEdid *edid, const guint8 *data, GError **error)
 			}
 		} else if (data[i+3] == GCM_DESCRIPTOR_COLOR_POINT) {
 			if (data[i+3+9] != 0xff) {
-				egg_debug ("extended EDID block(1) which contains a better gamma value");
+				g_debug ("extended EDID block(1) which contains a better gamma value");
 				priv->gamma = ((gfloat) data[i+3+9] / 100) + 1;
-				egg_debug ("gamma is overridden as %f", priv->gamma);
+				g_debug ("gamma is overridden as %f", priv->gamma);
 			}
 			if (data[i+3+14] != 0xff) {
-				egg_debug ("extended EDID block(2) which contains a better gamma value");
+				g_debug ("extended EDID block(2) which contains a better gamma value");
 				priv->gamma = ((gfloat) data[i+3+9] / 100) + 1;
-				egg_debug ("gamma is overridden as %f", priv->gamma);
+				g_debug ("gamma is overridden as %f", priv->gamma);
 			}
 		}
 	}
@@ -417,16 +585,16 @@ gcm_edid_parse (GcmEdid *edid, const guint8 *data, GError **error)
 	/* extension blocks */
 	extension_blocks = data[GCM_EDID_OFFSET_EXTENSION_BLOCK_COUNT];
 	if (extension_blocks > 0)
-		egg_warning ("%i extension blocks to parse", extension_blocks);
+		g_warning ("%i extension blocks to parse", extension_blocks);
 
 	/* calculate checksum */
 	priv->checksum = g_compute_checksum_for_data (G_CHECKSUM_MD5, data, 0x6c);
 
 	/* print what we've got */
-	egg_debug ("monitor name: %s", priv->monitor_name);
-	egg_debug ("serial number: %s", priv->serial_number);
-	egg_debug ("ascii string: %s", priv->eisa_id);
-	egg_debug ("checksum: %s", priv->checksum);
+	g_debug ("monitor name: %s", priv->monitor_name);
+	g_debug ("serial number: %s", priv->serial_number);
+	g_debug ("ascii string: %s", priv->eisa_id);
+	g_debug ("checksum: %s", priv->checksum);
 out:
 	return ret;
 }
@@ -468,6 +636,18 @@ gcm_edid_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec
 	case PROP_HEIGHT:
 		g_value_set_uint (value, priv->height);
 		break;
+	case PROP_WHITE:
+		g_value_set_boxed (value, g_boxed_copy (CD_TYPE_COLOR_XYZ, priv->white));
+		break;
+	case PROP_RED:
+		g_value_set_boxed (value, g_boxed_copy (CD_TYPE_COLOR_XYZ, priv->red));
+		break;
+	case PROP_GREEN:
+		g_value_set_boxed (value, g_boxed_copy (CD_TYPE_COLOR_XYZ, priv->green));
+		break;
+	case PROP_BLUE:
+		g_value_set_boxed (value, g_boxed_copy (CD_TYPE_COLOR_XYZ, priv->blue));
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -571,6 +751,39 @@ gcm_edid_class_init (GcmEdidClass *klass)
 				   G_PARAM_READABLE);
 	g_object_class_install_property (object_class, PROP_HEIGHT, pspec);
 
+	/**
+	 * GcmEdid:red:
+	 */
+	g_object_class_install_property (object_class,
+					 PROP_RED,
+					 g_param_spec_boxed ("red", NULL, NULL,
+							     CD_TYPE_COLOR_YXY,
+							     G_PARAM_READABLE));
+	/**
+	 * GcmEdid:green:
+	 */
+	g_object_class_install_property (object_class,
+					 PROP_GREEN,
+					 g_param_spec_boxed ("green", NULL, NULL,
+							     CD_TYPE_COLOR_YXY,
+							     G_PARAM_READABLE));
+	/**
+	 * GcmEdid:blue:
+	 */
+	g_object_class_install_property (object_class,
+					 PROP_BLUE,
+					 g_param_spec_boxed ("blue", NULL, NULL,
+							     CD_TYPE_COLOR_YXY,
+							     G_PARAM_READABLE));
+	/**
+	 * GcmEdid:white:
+	 */
+	g_object_class_install_property (object_class,
+					 PROP_WHITE,
+					 g_param_spec_boxed ("white", NULL, NULL,
+							     CD_TYPE_COLOR_YXY,
+							     G_PARAM_READABLE));
+
 	g_type_class_add_private (klass, sizeof (GcmEdidPrivate));
 }
 
@@ -588,6 +801,10 @@ gcm_edid_init (GcmEdid *edid)
 	edid->priv->checksum = NULL;
 	edid->priv->tables = gcm_tables_new ();
 	edid->priv->pnp_id = g_new0 (gchar, 4);
+	edid->priv->red = cd_color_yxy_new ();
+	edid->priv->green = cd_color_yxy_new ();
+	edid->priv->blue = cd_color_yxy_new ();
+	edid->priv->white = cd_color_yxy_new ();
 }
 
 /**
@@ -605,6 +822,10 @@ gcm_edid_finalize (GObject *object)
 	g_free (priv->eisa_id);
 	g_free (priv->checksum);
 	g_free (priv->pnp_id);
+	cd_color_yxy_free (priv->white);
+	cd_color_yxy_free (priv->red);
+	cd_color_yxy_free (priv->green);
+	cd_color_yxy_free (priv->blue);
 	g_object_unref (priv->tables);
 
 	G_OBJECT_CLASS (gcm_edid_parent_class)->finalize (object);
@@ -613,7 +834,7 @@ gcm_edid_finalize (GObject *object)
 /**
  * gcm_edid_new:
  *
- * Return value: a new GcmEdid object.
+ * Return value: a new #GcmEdid object.
  **/
 GcmEdid *
 gcm_edid_new (void)
