@@ -23,6 +23,7 @@
 #define __GCM_EDID_H
 
 #include <glib-object.h>
+#include <colord.h>
 
 G_BEGIN_DECLS
 
@@ -59,6 +60,7 @@ GcmEdid		*gcm_edid_new				(void);
 void		 gcm_edid_reset				(GcmEdid		*edid);
 gboolean	 gcm_edid_parse				(GcmEdid		*edid,
 							 const guint8		*data,
+							 gsize			 length,
 							 GError			**error);
 const gchar	*gcm_edid_get_monitor_name		(GcmEdid		*edid);
 const gchar	*gcm_edid_get_vendor_name		(GcmEdid		*edid);
@@ -69,6 +71,10 @@ const gchar	*gcm_edid_get_pnp_id			(GcmEdid		*edid);
 guint		 gcm_edid_get_width			(GcmEdid		*edid);
 guint		 gcm_edid_get_height			(GcmEdid		*edid);
 gfloat		 gcm_edid_get_gamma			(GcmEdid		*edid);
+const CdColorYxy *gcm_edid_get_red			(GcmEdid		*edid);
+const CdColorYxy *gcm_edid_get_green			(GcmEdid		*edid);
+const CdColorYxy *gcm_edid_get_blue			(GcmEdid		*edid);
+const CdColorYxy *gcm_edid_get_white			(GcmEdid		*edid);
 
 G_END_DECLS
 
