@@ -25,14 +25,12 @@
 #include <gtk/gtk.h>
 #include <math.h>
 #include <locale.h>
-
-#include "egg-debug.h"
+#include <colord.h>
 
 #include "gcm-profile.h"
-#include "gcm-profile-store.h"
 #include "gcm-utils.h"
-#include "gcm-xyz.h"
 #include "gcm-cie-widget.h"
+#include "gcm-debug.h"
 
 /**
  * gcm_import_add_cie_widget:
@@ -58,27 +56,23 @@ gcm_import_add_cie_widget (GtkDialog *dialog, GtkWidget *cie_widget)
 int
 main (int argc, char **argv)
 {
-	gboolean ret;
+	CdClient *client = NULL;
+	CdColorspace colorspace;
+	CdProfile *profile_tmp = NULL;
 	const gchar *copyright;
 	const gchar *description;
+	gboolean ret;
+	gchar **files = NULL;
+	GcmProfile *profile = NULL;
+	GError *error = NULL;
 	GFile *destination = NULL;
 	GFile *file = NULL;
-	gchar **files = NULL;
-	guint retval = 1;
-	GcmProfileStore *profile_store = NULL;
-	GcmProfile *profile = NULL;
-	GcmProfile *profile_tmp = NULL;
-	GcmColorspace colorspace;
-	GError *error = NULL;
 	GOptionContext *context;
 	GString *string = NULL;
-	GtkWidget *dialog;
 	GtkResponseType response;
 	GtkWidget *cie_widget = NULL;
-	GcmXyz *white = NULL;
-	GcmXyz *red = NULL;
-	GcmXyz *green = NULL;
-	GcmXyz *blue = NULL;
+	GtkWidget *dialog;
+	guint retval = 1;
 
 	const GOptionEntry options[] = {
 		{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &files,
@@ -97,7 +91,7 @@ main (int argc, char **argv)
 
 	context = g_option_context_new ("gnome-color-manager import program");
 	g_option_context_add_main_entries (context, options, NULL);
-	g_option_context_add_group (context, egg_debug_get_option_group ());
+	g_option_context_add_group (context, gcm_debug_get_option_group ());
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	g_option_context_parse (context, &argc, &argv, NULL);
 	g_option_context_free (context);
@@ -132,24 +126,15 @@ main (int argc, char **argv)
 	description = gcm_profile_get_description (profile);
 	copyright = gcm_profile_get_copyright (profile);
 	colorspace = gcm_profile_get_colorspace (profile);
-	g_object_get (profile,
-		      "white", &white,
-		      "red", &red,
-		      "green", &green,
-		      "blue", &blue,
-		      NULL);
 
 	/* use CIE widget */
 	cie_widget = gcm_cie_widget_new ();
-	gtk_widget_set_size_request (cie_widget, 200, 200);
 	g_object_set (cie_widget,
 		      "use-grid", FALSE,
 		      "use-whitepoint", FALSE,
-		      "white", white,
-		      "red", red,
-		      "green", green,
-		      "blue", blue,
 		      NULL);
+	gtk_widget_set_size_request (cie_widget, 200, 200);
+	gcm_cie_widget_set_from_profile (cie_widget, profile);
 
 	/* check file does't already exist as a file */
 	destination = gcm_utils_get_profile_destination (file);
@@ -165,14 +150,32 @@ main (int argc, char **argv)
 	}
 
 	/* check file does't already exist as system-wide */
-	profile_store = gcm_profile_store_new ();
-	gcm_profile_store_search (profile_store, GCM_PROFILE_STORE_SEARCH_SYSTEM);
-	profile_tmp = gcm_profile_store_get_by_checksum (profile_store, gcm_profile_get_checksum (profile));
+	client = cd_client_new ();
+	ret = cd_client_connect_sync (client,
+				      NULL,
+				      &error);
+	if (!ret) {
+		g_warning ("failed to connect to colord: %s",
+			   error->message);
+		g_error_free (error);
+		goto out;
+	}
+	profile_tmp = cd_client_find_profile_sync (client,
+						   gcm_profile_get_checksum (profile),
+						   NULL,
+						   NULL);
 	if (profile_tmp != NULL) {
 		/* TRANSLATORS: color profile already been installed */
-		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE, _("ICC profile already installed system-wide"));
+		dialog = gtk_message_dialog_new (NULL,
+						 GTK_DIALOG_MODAL,
+						 GTK_MESSAGE_INFO,
+						 GTK_BUTTONS_CLOSE,
+						 _("ICC profile already installed system-wide"));
 		gtk_window_set_icon_name (GTK_WINDOW (dialog), GCM_STOCK_ICON);
-		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "%s\n%s", description, copyright);
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+							  "%s\n%s",
+							  description,
+							  copyright);
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
 		goto out;
@@ -203,7 +206,7 @@ main (int argc, char **argv)
 	gcm_import_add_cie_widget (GTK_DIALOG(dialog), cie_widget);
 
 	/* only show the cie widget if we have RGB data */
-	if (colorspace != GCM_COLORSPACE_RGB)
+	if (colorspace != CD_COLORSPACE_RGB)
 		gtk_widget_hide (cie_widget);
 
 	gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
@@ -226,31 +229,15 @@ main (int argc, char **argv)
 		gtk_widget_destroy (dialog);
 		goto out;
 	}
-
-	/* open up the preferences */
-	ret = g_spawn_command_line_async (BINDIR "/gcm-prefs", &error);
-	if (!ret) {
-		egg_warning ("failed to spawn preferences: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
 out:
 	if (file != NULL)
 		g_object_unref (file);
-	if (white != NULL)
-		g_object_unref (white);
-	if (red != NULL)
-		g_object_unref (red);
-	if (green != NULL)
-		g_object_unref (green);
-	if (blue != NULL)
-		g_object_unref (blue);
 	if (string != NULL)
 		g_string_free (string, TRUE);
 	if (profile != NULL)
 		g_object_unref (profile);
-	if (profile_store != NULL)
-		g_object_unref (profile_store);
+	if (client != NULL)
+		g_object_unref (client);
 	if (profile_tmp != NULL)
 		g_object_unref (profile_tmp);
 	if (destination != NULL)
