@@ -25,12 +25,11 @@
 #include <gtk/gtk.h>
 #include <locale.h>
 
-#include "egg-debug.h"
-
 #include "gcm-utils.h"
 #include "gcm-profile.h"
 #include "gcm-x11-output.h"
 #include "gcm-x11-screen.h"
+#include "gcm-debug.h"
 
 /**
  * gcm_inspect_print_data_info:
@@ -46,7 +45,7 @@ gcm_inspect_print_data_info (const gchar *title, const guint8 *data, gsize lengt
 	profile = gcm_profile_new ();
 	ret = gcm_profile_parse_data (profile, data, length, &error);
 	if (!ret) {
-		egg_warning ("failed to parse data: %s", error->message);
+		g_warning ("failed to parse data: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -89,7 +88,7 @@ gcm_inspect_show_x11_atoms (void)
 	screen = gcm_x11_screen_new ();
 	ret = gcm_x11_screen_assign (screen, NULL, &error);
 	if (!ret) {
-		egg_warning ("failed to get outputs: %s", error->message);
+		g_warning ("failed to get outputs: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -97,7 +96,7 @@ gcm_inspect_show_x11_atoms (void)
 	/* get profile from XServer */
 	ret = gcm_x11_screen_get_profile_data (screen, &data, &length, &error);
 	if (!ret) {
-		egg_warning ("failed to get XServer profile data: %s", error->message);
+		g_warning ("failed to get XServer profile data: %s", error->message);
 		g_error_free (error);
 		/* non-fatal */
 		error = NULL;
@@ -109,7 +108,7 @@ gcm_inspect_show_x11_atoms (void)
 	/* get profile from XServer */
 	ret = gcm_x11_screen_get_protocol_version (screen, &major, &minor, &error);
 	if (!ret) {
-		egg_warning ("failed to get XServer protocol version: %s", error->message);
+		g_warning ("failed to get XServer protocol version: %s", error->message);
 		g_error_free (error);
 		/* non-fatal */
 		error = NULL;
@@ -122,7 +121,7 @@ gcm_inspect_show_x11_atoms (void)
 	outputs = gcm_x11_screen_get_outputs (screen, &error);
 	if (outputs == NULL) {
 		ret = FALSE;
-		egg_warning ("failed to get outputs: %s", error->message);
+		g_warning ("failed to get outputs: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -136,7 +135,7 @@ gcm_inspect_show_x11_atoms (void)
 		/* get profile from XServer */
 		ret = gcm_x11_output_get_profile_data (output, &data_tmp, &length, &error);
 		if (!ret) {
-			egg_warning ("failed to get output profile data: %s", error->message);
+			g_warning ("failed to get output profile data: %s", error->message);
 			/* TRANSLATORS: this is when the profile has not been set */
 			g_print ("%s %s\n", title, _("not set"));
 			g_error_free (error);
@@ -295,66 +294,6 @@ out:
 	return ret;
 }
 
-/**
- * gcm_inspect_show_profiles_for_devices:
- **/
-static gboolean
-gcm_inspect_show_profiles_for_devices (void)
-{
-	gboolean ret = FALSE;
-	GDBusConnection *connection;
-	GError *error = NULL;
-	guint i;
-	const gchar **devices = NULL;
-	GVariant *response = NULL;
-	GVariant *response_child = NULL;
-
-	/* get a session bus connection */
-	connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
-	if (connection == NULL) {
-		/* TRANSLATORS: no DBus session bus */
-		g_print ("%s %s\n", _("Failed to connect to session bus:"), error->message);
-		g_error_free (error);
-		goto out;
-	}
-
-	/* execute sync method */
-	response = g_dbus_connection_call_sync (connection,
-						GCM_DBUS_SERVICE,
-						GCM_DBUS_PATH,
-						GCM_DBUS_INTERFACE,
-						"GetDevices",
-						NULL,
-						G_VARIANT_TYPE ("(as)"),
-						G_DBUS_CALL_FLAGS_NONE,
-						-1, NULL, &error);
-	if (response == NULL) {
-		/* TRANSLATORS: the DBus method failed */
-		g_print ("%s %s\n", _("The request failed:"), error->message);
-		g_error_free (error);
-		goto out;
-	}
-
-	/* print each device */
-	response_child = g_variant_get_child_value (response, 0);
-	devices = g_variant_get_strv (response_child, NULL);
-	for (i=0; devices[i] != NULL; i++) {
-		ret = gcm_inspect_show_profiles_for_device (devices[i]);
-		if (!ret)
-			goto out;
-	}
-
-	/* success */
-	ret = TRUE;
-out:
-	g_free (devices);
-	if (response != NULL)
-		g_variant_unref (response);
-	if (response_child != NULL)
-		g_variant_unref (response_child);
-	return ret;
-}
-
 /**
  * gcm_inspect_show_profile_for_window:
  **/
@@ -602,7 +541,7 @@ main (int argc, char **argv)
 	/* TRANSLATORS: just dumps the EDID to disk */
 	context = g_option_context_new (_("EDID inspect program"));
 	g_option_context_add_main_entries (context, options, NULL);
-	g_option_context_add_group (context, egg_debug_get_option_group ());
+	g_option_context_add_group (context, gcm_debug_get_option_group ());
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	g_option_context_parse (context, &argc, &argv, NULL);
 	g_option_context_free (context);
@@ -616,14 +555,14 @@ main (int argc, char **argv)
 	if (xid != 0)
 		gcm_inspect_show_profile_for_window (xid);
 	if (type != NULL) {
-		if (gcm_device_kind_from_string (type) == GCM_DEVICE_KIND_UNKNOWN &&
-		    gcm_profile_kind_from_string (type) == GCM_PROFILE_KIND_UNKNOWN) {
+		if (cd_device_kind_from_string (type) == CD_DEVICE_KIND_UNKNOWN &&
+		    cd_profile_kind_from_string (type) == CD_PROFILE_KIND_UNKNOWN) {
 			/* TRANSLATORS: this is when the user does --type=mickeymouse */
 			g_print ("%s\n", _("Device or profile type not recognized, recognised types are:"));
-			for (i=1; i<GCM_DEVICE_KIND_LAST; i++)
-				g_print (" - %s\n", gcm_device_kind_to_string (i));
-			for (i=1; i<GCM_PROFILE_KIND_LAST; i++)
-				g_print (" - %s\n", gcm_profile_kind_to_string (i));
+			for (i=1; i<CD_DEVICE_KIND_LAST; i++)
+				g_print (" - %s\n", cd_device_kind_to_string (i));
+			for (i=1; i<CD_PROFILE_KIND_LAST; i++)
+				g_print (" - %s\n", cd_profile_kind_to_string (i));
 		} else {
 			/* show device profiles */
 			gcm_inspect_show_profiles_for_type (type);
@@ -631,7 +570,6 @@ main (int argc, char **argv)
 	}
 	if (dump) {
 		gcm_inspect_get_properties ();
-		gcm_inspect_show_profiles_for_devices ();
 	}
 
 	g_free (device_id);
