@@ -30,26 +30,23 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 #include <lcms2.h>
+#include <colord.h>
 
 #include "gcm-calibrate-argyll.h"
-#include "gcm-sensor-client.h"
-#include "gcm-profile-store.h"
 #include "gcm-utils.h"
-#include "gcm-color.h"
 #include "gcm-debug.h"
 
-static GtkBuilder *builder = NULL;
-static GtkWidget *info_bar_hardware = NULL;
-static GtkWidget *info_bar_hardware_label = NULL;
-static GcmCalibrate *calibrate = NULL;
-static GcmProfileStore *profile_store = NULL;
+static CdClient *client = NULL;
 static const gchar *profile_filename = NULL;
 static gboolean done_measure = FALSE;
-static GcmSensor *sensor = NULL;
-static GcmColorXYZ last_sample;
+static GcmCalibrate *calibrate = NULL;
+static CdColorXYZ last_sample;
+static CdSensor *sensor = NULL;
 static gdouble last_ambient = -1.0f;
+static GtkBuilder *builder = NULL;
+static GtkWidget *info_bar_hardware_label = NULL;
+static GtkWidget *info_bar_hardware = NULL;
 static guint xid = 0;
-static GcmSensorClient *sensor_client = NULL;
 
 enum {
 	GCM_PREFS_COMBO_COLUMN_TEXT,
@@ -90,27 +87,32 @@ gcm_picker_set_pixbuf_color (GdkPixbuf *pixbuf, gchar red, gchar green, gchar bl
 static void
 gcm_picker_refresh_results (void)
 {
-	GtkImage *image;
-	GtkLabel *label;
-	GdkPixbuf *pixbuf = NULL;
-	GcmColorRGBint color_rgb;
-	GcmColorLab color_lab;
-	GcmColorXYZ color_xyz;
-	GcmColorXYZ color_error;
-	gchar *text_xyz = NULL;
+	cmsCIExyY xyY;
+	cmsHPROFILE profile_lab;
+	cmsHPROFILE profile_rgb;
+	cmsHPROFILE profile_xyz;
+	cmsHTRANSFORM transform_error;
+	cmsHTRANSFORM transform_lab;
+	cmsHTRANSFORM transform_rgb;
+	gboolean ret;
+	gchar *text_ambient = NULL;
+	gchar *text_error = NULL;
 	gchar *text_lab = NULL;
 	gchar *text_rgb = NULL;
-	gchar *text_error = NULL;
-	gchar *text_ambient = NULL;
-	cmsHPROFILE profile_xyz;
-	cmsHPROFILE profile_rgb;
-	cmsHPROFILE profile_lab;
-	cmsHTRANSFORM transform_rgb;
-	cmsHTRANSFORM transform_lab;
-	cmsHTRANSFORM transform_error;
+	gchar *text_temperature = NULL;
+	gchar *text_whitepoint = NULL;
+	gchar *text_xyz = NULL;
+	CdColorLab color_lab;
+	CdColorRGB8 color_rgb;
+	CdColorXYZ color_error;
+	CdColorXYZ color_xyz;
+	GdkPixbuf *pixbuf = NULL;
+	gdouble temperature = 0.0f;
+	GtkImage *image;
+	GtkLabel *label;
 
 	/* copy as we're modifying the value */
-	gcm_color_copy_XYZ (&last_sample, &color_xyz);
+	cd_color_copy_xyz (&last_sample, &color_xyz);
 
 	/* create new pixbuf of the right size */
 	pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, 200, 200);
@@ -126,9 +128,15 @@ gcm_picker_refresh_results (void)
 	profile_lab = cmsCreateLab4Profile (cmsD50_xyY ());
 
 	/* create transforms */
-	transform_rgb = cmsCreateTransform (profile_xyz, TYPE_XYZ_DBL, profile_rgb, TYPE_RGB_8, INTENT_PERCEPTUAL, 0);
-	transform_lab = cmsCreateTransform (profile_xyz, TYPE_XYZ_DBL, profile_lab, TYPE_Lab_DBL, INTENT_PERCEPTUAL, 0);
-	transform_error = cmsCreateTransform (profile_rgb, TYPE_RGB_8, profile_xyz, TYPE_XYZ_DBL, INTENT_PERCEPTUAL, 0);
+	transform_rgb = cmsCreateTransform (profile_xyz, TYPE_XYZ_DBL,
+					    profile_rgb, TYPE_RGB_8,
+					    INTENT_PERCEPTUAL, 0);
+	transform_lab = cmsCreateTransform (profile_xyz, TYPE_XYZ_DBL,
+					    profile_lab, TYPE_Lab_DBL,
+					    INTENT_PERCEPTUAL, 0);
+	transform_error = cmsCreateTransform (profile_rgb, TYPE_RGB_8,
+					      profile_xyz, TYPE_XYZ_DBL,
+					      INTENT_PERCEPTUAL, 0);
 
 	cmsDoTransform (transform_rgb, &color_xyz, &color_rgb, 1);
 	cmsDoTransform (transform_lab, &color_xyz, &color_lab, 1);
@@ -144,14 +152,37 @@ gcm_picker_refresh_results (void)
 
 	/* set XYZ */
 	label = GTK_LABEL (gtk_builder_get_object (builder, "label_xyz"));
-	text_xyz = g_strdup_printf ("%.3f, %.3f, %.3f", last_sample.X, last_sample.Y, last_sample.Z);
+	text_xyz = g_strdup_printf ("%.3f, %.3f, %.3f",
+				    last_sample.X,
+				    last_sample.Y,
+				    last_sample.Z);
 	gtk_label_set_label (label, text_xyz);
 
 	/* set LAB */
 	label = GTK_LABEL (gtk_builder_get_object (builder, "label_lab"));
-	text_lab = g_strdup_printf ("%.3f, %.3f, %.3f", color_lab.L, color_lab.a, color_lab.b);
+	text_lab = g_strdup_printf ("%.3f, %.3f, %.3f",
+				    color_lab.L,
+				    color_lab.a,
+				    color_lab.b);
 	gtk_label_set_label (label, text_lab);
 
+	/* set whitepoint */
+	cmsXYZ2xyY (&xyY, (cmsCIEXYZ *)&last_sample);
+	label = GTK_LABEL (gtk_builder_get_object (builder, "label_whitepoint"));
+	text_whitepoint = g_strdup_printf ("%.3f,%.3f [%.3f]",
+					   xyY.x, xyY.y, xyY.Y);
+	gtk_label_set_label (label, text_whitepoint);
+
+	/* set temperature */
+	ret = cmsTempFromWhitePoint (&temperature, &xyY);
+	if (ret) {
+		/* round to nearest 10K */
+		temperature = (((guint) temperature) / 10) * 10;
+	}
+	label = GTK_LABEL (gtk_builder_get_object (builder, "label_temperature"));
+	text_temperature = g_strdup_printf ("%.0fK", temperature);
+	gtk_label_set_label (label, text_temperature);
+
 	/* set RGB */
 	label = GTK_LABEL (gtk_builder_get_object (builder, "label_rgb"));
 	text_rgb = g_strdup_printf ("%i, %i, %i (#%02X%02X%02X)",
@@ -162,11 +193,18 @@ gcm_picker_refresh_results (void)
 
 	/* set error */
 	label = GTK_LABEL (gtk_builder_get_object (builder, "label_error"));
-	text_error = g_strdup_printf ("%.1f%%, %.1f%%, %.1f%%",
-				      ABS ((color_error.X - color_xyz.X) / color_xyz.X * 100),
-				      ABS ((color_error.Y - color_xyz.Y) / color_xyz.Y * 100),
-				      ABS ((color_error.Z - color_xyz.Z) / color_xyz.Z * 100));
-	gtk_label_set_label (label, text_error);
+	if (color_xyz.X > 0.01f &&
+	    color_xyz.Y > 0.01f &&
+	    color_xyz.Z > 0.01f) {
+		text_error = g_strdup_printf ("%.1f%%, %.1f%%, %.1f%%",
+					      ABS ((color_error.X - color_xyz.X) / color_xyz.X * 100),
+					      ABS ((color_error.Y - color_xyz.Y) / color_xyz.Y * 100),
+					      ABS ((color_error.Z - color_xyz.Z) / color_xyz.Z * 100));
+		gtk_label_set_label (label, text_error);
+	} else {
+		/* TRANSLATORS: this is when the error is invalid */
+		gtk_label_set_label (label, _("Unknown"));
+	}
 
 	/* set ambient */
 	label = GTK_LABEL (gtk_builder_get_object (builder, "label_ambient"));
@@ -182,11 +220,13 @@ gcm_picker_refresh_results (void)
 	image = GTK_IMAGE (gtk_builder_get_object (builder, "image_preview"));
 	gtk_image_set_from_pixbuf (image, pixbuf);
 
-	g_free (text_xyz);
+	g_free (text_ambient);
+	g_free (text_error);
 	g_free (text_lab);
 	g_free (text_rgb);
-	g_free (text_error);
-	g_free (text_ambient);
+	g_free (text_temperature);
+	g_free (text_whitepoint);
+	g_free (text_xyz);
 	if (pixbuf != NULL)
 		g_object_unref (pixbuf);
 }
@@ -222,26 +262,54 @@ gcm_picker_measure_cb (GtkWidget *widget, gpointer data)
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "image_preview"));
 	gtk_image_set_from_file (GTK_IMAGE (widget), DATADIR "/icons/hicolor/64x64/apps/gnome-color-manager.png");
 
-	if (gcm_sensor_is_native (sensor)) {
+	if (cd_sensor_get_native (sensor)) {
 
-		/* set mode */
-		gcm_sensor_set_output_type (sensor, GCM_SENSOR_OUTPUT_TYPE_LCD);
+		/* lock */
+		ret = cd_sensor_lock_sync (sensor,
+					   NULL,
+					   &error);
+		if (!ret) {
+			g_warning ("failed to lock: %s", error->message);
+			g_error_free (error);
+			goto out;
+		}
 
-		/* get ambient */
-		ret = gcm_sensor_get_ambient (sensor, NULL, &last_ambient, &error);
+		/* get color */
+		ret = cd_sensor_get_sample_sync (sensor,
+						 CD_SENSOR_CAP_LCD,
+						 &last_sample,
+						 NULL,
+						 NULL,
+						 &error);
 		if (!ret) {
 			g_warning ("failed to get ambient: %s", error->message);
 			g_error_free (error);
 			goto out;
 		}
 
-		/* sample color */
-		ret = gcm_sensor_sample (sensor, NULL, &last_sample, &error);
+		/* get ambient */
+		ret = cd_sensor_get_sample_sync (sensor,
+						 CD_SENSOR_CAP_AMBIENT,
+						 NULL,
+						 &last_ambient,
+						 NULL,
+						 &error);
 		if (!ret) {
-			g_warning ("failed to measure: %s", error->message);
+			g_warning ("failed to get ambient: %s", error->message);
 			g_error_free (error);
 			goto out;
 		}
+
+		/* unlock */
+		ret = cd_sensor_unlock_sync (sensor,
+					     NULL,
+					     &error);
+		if (!ret) {
+			g_warning ("failed to lock: %s", error->message);
+			g_error_free (error);
+			goto out;
+		}
+
 		gcm_picker_refresh_results ();
 		gcm_picker_got_results ();
 	} else {
@@ -262,9 +330,11 @@ out:
  * gcm_picker_xyz_notify_cb:
  **/
 static void
-gcm_picker_xyz_notify_cb (GcmCalibrate *calibrate_, GParamSpec *pspec, gpointer user_data)
+gcm_picker_xyz_notify_cb (GcmCalibrate *calibrate_,
+			  GParamSpec *pspec,
+			  gpointer user_data)
 {
-	GcmColorXYZ *xyz;
+	CdColorXYZ *xyz;
 
 	/* get new value */
 	g_object_get (calibrate, "xyz", &xyz, NULL);
@@ -277,7 +347,7 @@ gcm_picker_xyz_notify_cb (GcmCalibrate *calibrate_, GParamSpec *pspec, gpointer
 
 	gcm_picker_refresh_results ();
 	gcm_picker_got_results ();
-	gcm_color_free_XYZ (xyz);
+	cd_color_xyz_free (xyz);
 }
 
 /**
@@ -313,30 +383,40 @@ gcm_picker_delete_event_cb (GtkWidget *widget, GdkEvent *event, gpointer data)
  * gcm_picker_sensor_client_setup_ui:
  **/
 static void
-gcm_picker_sensor_client_setup_ui (GcmSensorClient *_sensor_client)
+gcm_picker_sensor_client_setup_ui (void)
 {
 	gboolean ret = FALSE;
 	GtkWidget *widget;
+	GPtrArray *sensors;
+	GError *error = NULL;
 
 	/* no present */
-	sensor = gcm_sensor_client_get_sensor (sensor_client);
-	if (sensor == NULL) {
-		/* TRANSLATORS: this is displayed the user has not got suitable hardware */
-		gtk_label_set_label (GTK_LABEL (info_bar_hardware_label), _("No colorimeter is attached."));
+	sensors = cd_client_get_sensors_sync (client, NULL, &error);
+	if (sensors == NULL) {
+		g_warning ("%s", error->message);
+		g_error_free (error);
 		goto out;
 	}
+	if (sensors->len == 0) {
+		/* TRANSLATORS: this is displayed the user has not got suitable hardware */
+		gtk_label_set_label (GTK_LABEL (info_bar_hardware_label),
+				    _("No colorimeter is attached."));
+		goto out;
+	}
+	sensor = g_object_ref (g_ptr_array_index (sensors, 0));
 
 #ifndef HAVE_VTE
-	if (!gcm_sensor_is_native (sensor)) {
+	if (!cd_sensor_get_native (sensor)) {
 		 /* TRANSLATORS: this is displayed if VTE support is not enabled */
-		gtk_label_set_label (GTK_LABEL (info_bar_hardware_label), _("This application was compiled without VTE support."));
+		gtk_label_set_label (GTK_LABEL (info_bar_hardware_label),
+				     _("This application was compiled without VTE support."));
 		goto out;
 	}
 #endif
 
 #if 0
 	/* no support */
-	ret = gcm_sensor_supports_spot (sensor);
+	ret = cd_sensor_supports_spot (sensor);
 	if (!ret) {
 		/* TRANSLATORS: this is displayed the user has not got suitable hardware */
 		gtk_label_set_label (GTK_LABEL (info_bar_hardware_label), _("The attached colorimeter is not capable of reading a spot color."));
@@ -347,6 +427,8 @@ gcm_picker_sensor_client_setup_ui (GcmSensorClient *_sensor_client)
 #endif
 
 out:
+	if (sensors != NULL)
+		g_ptr_array_unref (sensors);
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "button_measure"));
 	gtk_widget_set_sensitive (widget, ret);
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "expander_results"));
@@ -358,9 +440,11 @@ out:
  * gcm_picker_sensor_client_changed_cb:
  **/
 static void
-gcm_picker_sensor_client_changed_cb (GcmSensorClient *_sensor_client, gpointer user_data)
+gcm_picker_sensor_client_changed_cb (CdClient *_client,
+				     CdSensor *_sensor,
+				     gpointer user_data)
 {
-	gcm_picker_sensor_client_setup_ui (sensor_client);
+	gcm_picker_sensor_client_setup_ui ();
 }
 
 /**
@@ -400,7 +484,7 @@ gcm_prefs_space_combo_changed_cb (GtkWidget *widget, gpointer data)
 	gboolean ret;
 	GtkTreeIter iter;
 	GtkTreeModel *model;
-	GcmProfile *profile = NULL;
+	CdProfile *profile = NULL;
 
 	/* no selection */
 	ret = gtk_combo_box_get_active_iter (GTK_COMBO_BOX(widget), &iter);
@@ -415,7 +499,7 @@ gcm_prefs_space_combo_changed_cb (GtkWidget *widget, gpointer data)
 	if (profile == NULL)
 		goto out;
 
-	profile_filename = gcm_profile_get_filename (profile);
+	profile_filename = cd_profile_get_filename (profile);
 	g_debug ("changed picker space %s", profile_filename);
 
 	gcm_picker_refresh_results ();
@@ -433,8 +517,9 @@ gcm_prefs_set_combo_simple_text (GtkWidget *combo_box)
 	GtkCellRenderer *renderer;
 	GtkListStore *store;
 
-	store = gtk_list_store_new (2, G_TYPE_STRING, GCM_TYPE_PROFILE);
-	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (store), GCM_PREFS_COMBO_COLUMN_TEXT, GTK_SORT_ASCENDING);
+	store = gtk_list_store_new (2, G_TYPE_STRING, CD_TYPE_PROFILE);
+	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (store),
+					      GCM_PREFS_COMBO_COLUMN_TEXT, GTK_SORT_ASCENDING);
 	gtk_combo_box_set_model (GTK_COMBO_BOX (combo_box), GTK_TREE_MODEL (store));
 	g_object_unref (store);
 
@@ -454,7 +539,7 @@ gcm_prefs_set_combo_simple_text (GtkWidget *combo_box)
  * gcm_prefs_combobox_add_profile:
  **/
 static void
-gcm_prefs_combobox_add_profile (GtkWidget *widget, GcmProfile *profile, GtkTreeIter *iter)
+gcm_prefs_combobox_add_profile (GtkWidget *widget, CdProfile *profile, GtkTreeIter *iter)
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter_tmp;
@@ -466,7 +551,7 @@ gcm_prefs_combobox_add_profile (GtkWidget *widget, GcmProfile *profile, GtkTreeI
 
 	/* also add profile */
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX(widget));
-	description = gcm_profile_get_description (profile);
+	description = cd_profile_get_title (profile);
 	gtk_list_store_append (GTK_LIST_STORE(model), iter);
 	gtk_list_store_set (GTK_LIST_STORE(model), iter,
 			    GCM_PREFS_COMBO_COLUMN_TEXT, description,
@@ -480,44 +565,74 @@ gcm_prefs_combobox_add_profile (GtkWidget *widget, GcmProfile *profile, GtkTreeI
 static void
 gcm_prefs_setup_space_combobox (GtkWidget *widget)
 {
-	GcmProfile *profile;
-	guint i;
+	CdColorspace colorspace;
+	CdDevice *device_tmp;
+	CdProfile *profile;
 	const gchar *filename;
-	GcmColorspace colorspace;
+	gboolean has_colorspace_description;
 	gboolean has_profile = FALSE;
 	gboolean has_vcgt;
-	gboolean has_colorspace_description;
 	gchar *text = NULL;
+	GError *error = NULL;
+	GPtrArray *devices = NULL;
 	GPtrArray *profile_array = NULL;
 	GtkTreeIter iter;
 	GtkTreeModel *model;
+	guint i;
 
 	/* get new list */
-	profile_array = gcm_profile_store_get_array (profile_store);
+	profile_array = cd_client_get_profiles_sync (client,
+						     NULL,
+						     &error);
+	if (profile_array == NULL) {
+		g_warning ("failed to get profiles: %s",
+			   error->message);
+		g_error_free (error);
+		goto out;
+	}
 
 	/* update each list */
 	for (i=0; i<profile_array->len; i++) {
 		profile = g_ptr_array_index (profile_array, i);
 
 		/* only for correct kind */
-		has_vcgt = gcm_profile_get_has_vcgt (profile);
+		has_vcgt = cd_profile_get_has_vcgt (profile);
 		has_colorspace_description = gcm_profile_has_colorspace_description (profile);
-		colorspace = gcm_profile_get_colorspace (profile);
+		colorspace = cd_profile_get_colorspace (profile);
 		if (!has_vcgt && has_colorspace_description &&
-		    colorspace == GCM_COLORSPACE_RGB) {
+		    colorspace == CD_COLORSPACE_RGB) {
 			gcm_prefs_combobox_add_profile (widget, profile, &iter);
 
 			/* set active option */
-			filename = gcm_profile_get_filename (profile);
+			filename = cd_profile_get_filename (profile);
 			if (g_strcmp0 (filename, profile_filename) == 0)
 				gtk_combo_box_set_active_iter (GTK_COMBO_BOX (widget), &iter);
 			has_profile = TRUE;
 		}
 	}
+
+	/* add device profiles */
+	devices = cd_client_get_devices_by_kind_sync (client,
+						      CD_DEVICE_KIND_DISPLAY,
+						      NULL,
+						      &error);
+	for (i=0; i<devices->len; i++) {
+		device_tmp = g_ptr_array_index (devices, i);
+		profile = cd_device_get_default_profile (device_tmp);
+		if (profile == NULL)
+			continue;
+
+		/* add device profile */
+		gcm_prefs_combobox_add_profile (widget, profile, NULL);
+		g_object_unref (profile);
+		has_profile = TRUE;
+	}
+
 	if (!has_profile) {
-		/* TRANSLATORS: this is when there are no profiles that can be used; the search term is either "RGB" or "CMYK" */
+		/* TRANSLATORS: this is when there are no profiles that can be used;
+		 * the search term is either "RGB" or "CMYK" */
 		text = g_strdup_printf (_("No %s color spaces available"),
-					gcm_colorspace_to_localised_string (GCM_COLORSPACE_RGB));
+					cd_colorspace_to_localised_string (CD_COLORSPACE_RGB));
 		model = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
 		gtk_list_store_append (GTK_LIST_STORE(model), &iter);
 		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
@@ -526,6 +641,9 @@ gcm_prefs_setup_space_combobox (GtkWidget *widget)
 		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
 		gtk_widget_set_sensitive (widget, FALSE);
 	}
+out:
+	if (devices != NULL)
+		g_ptr_array_unref (devices);
 	if (profile_array != NULL)
 		g_ptr_array_unref (profile_array);
 	g_free (text);
@@ -548,14 +666,17 @@ gcm_picker_activate_cb (GApplication *application, gpointer user_data)
 static void
 gcm_picker_startup_cb (GApplication *application, gpointer user_data)
 {
-	guint retval = 0;
+	gboolean ret;
 	GError *error = NULL;
 	GtkWidget *main_window;
 	GtkWidget *widget;
+	guint retval = 0;
 
 	/* get UI */
 	builder = gtk_builder_new ();
-	retval = gtk_builder_add_from_file (builder, GCM_DATA "/gcm-picker.ui", &error);
+	retval = gtk_builder_add_from_file (builder,
+					    GCM_DATA "/gcm-picker.ui",
+					    &error);
 	if (retval == 0) {
 		g_warning ("failed to load ui: %s", error->message);
 		g_error_free (error);
@@ -588,11 +709,7 @@ gcm_picker_startup_cb (GApplication *application, gpointer user_data)
 	                                   GCM_DATA G_DIR_SEPARATOR_S "icons");
 
 	/* create a last sample */
-	//gcm_color_xyz_clear (&last_sample);
-
-	/* use the color device */
-	sensor_client = gcm_sensor_client_new ();
-	g_signal_connect (sensor_client, "changed", G_CALLBACK (gcm_picker_sensor_client_changed_cb), NULL);
+	//cd_color_xyz_clear (&last_sample);
 
 	/* set the parent window if it is specified */
 	if (xid != 0) {
@@ -617,12 +734,24 @@ gcm_picker_startup_cb (GApplication *application, gpointer user_data)
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "vbox1"));
 	gtk_box_pack_start (GTK_BOX(widget), info_bar_hardware, FALSE, FALSE, 0);
 
-	/* disable some ui if no hardware */
-	gcm_picker_sensor_client_setup_ui (sensor_client);
-
 	/* maintain a list of profiles */
-	profile_store = gcm_profile_store_new ();
-	gcm_profile_store_search (profile_store, GCM_PROFILE_STORE_SEARCH_ALL);
+	client = cd_client_new ();
+	ret = cd_client_connect_sync (client,
+				      NULL,
+				      &error);
+	if (!ret) {
+		g_warning ("failed to connect to colord: %s",
+			   error->message);
+		g_error_free (error);
+		goto out;
+	}
+	g_signal_connect (client, "sensor-added",
+			  G_CALLBACK (gcm_picker_sensor_client_changed_cb), NULL);
+	g_signal_connect (client, "sensor-removed",
+			  G_CALLBACK (gcm_picker_sensor_client_changed_cb), NULL);
+
+	/* disable some ui if no hardware */
+	gcm_picker_sensor_client_setup_ui ();
 
 	/* default to AdobeRGB */
 	profile_filename = "/usr/share/color/icc/Argyll/ClayRGB1998.icm";
@@ -695,10 +824,8 @@ main (int argc, char *argv[])
 	status = g_application_run (G_APPLICATION (application), argc, argv);
 
 	g_object_unref (application);
-	if (profile_store != NULL)
-		g_object_unref (profile_store);
-	if (sensor_client != NULL)
-		g_object_unref (sensor_client);
+	if (client != NULL)
+		g_object_unref (client);
 	if (calibrate != NULL)
 		g_object_unref (calibrate);
 	if (builder != NULL)
